@@ -50,6 +50,7 @@ use NewsExtractor::SiteSpecificExtractor::www_ustv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_mdnkids_com;
 use NewsExtractor::SiteSpecificExtractor::www_nownews_com;
 use NewsExtractor::SiteSpecificExtractor::www_penghutimes_com;
+use NewsExtractor::SiteSpecificExtractor::www_aljazeera_com;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -67,6 +68,7 @@ has extractor => (
 
 use constant {
     SiteSpecificExtractorByHost => {
+        'www.aljazeera.com' => 'NewsExtractor::SiteSpecificExtractor::www_aljazeera_com',
         'www.penghutimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_penghutimes_com',
         'www.ustv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ustv_com_tw',
         'www.epochtimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_epochtimes_com',
